Struct netcore::transport::tcp::TcpSocket [−][src]
pub struct TcpSocket { /* fields omitted */ }Expand description
A wrapper around a tokio TcpStream
In order to properly implement the AsyncRead/AsyncWrite traits we need to wrap a TcpStream to ensure that the “close” method actually closes the write half of the TcpStream. This is because the “close” method on a TcpStream just performs a no-op instead of actually shutting down the write side of the TcpStream.
Implementations