Struct netcore::transport::tcp::TcpTransport [−][src]
Transport to build TCP connections
Fields
ttl: Option<u32>TTL to set for opened sockets, or None to keep default.
nodelay: Option<bool>TCP_NODELAY to set for opened sockets, or None to keep default.